project ITARJ

ITARJ - Is This A Real Job - is a python console app that allows users to register and view fake job alerts. It also allows a user to flag a registered fake job as false with prove.

for a user to add a fake job alert, the user must be logged in or create a new account if there is no existing accounts. User can view jobs by proving a keyword to search